# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.report.calculation import Calculation as Calculation
from ...lo.report.fixed_line import FixedLine as FixedLine
from ...lo.report.fixed_text import FixedText as FixedText
from ...lo.report.force_new_page import ForceNewPage as ForceNewPage
from ...lo.report.format_condition import FormatCondition as FormatCondition
from ...lo.report.formatted_field import FormattedField as FormattedField
from ...lo.report.function import Function as Function
from ...lo.report.group import Group as Group
from ...lo.report.group_keep_together import GroupKeepTogether as GroupKeepTogether
from ...lo.report.group_on import GroupOn as GroupOn
from ...lo.report.groups import Groups as Groups
from ...lo.report.image_control import ImageControl as ImageControl
from ...lo.report.keep_together import KeepTogether as KeepTogether
from ...lo.report.report_control_format import ReportControlFormat as ReportControlFormat
from ...lo.report.report_control_model import ReportControlModel as ReportControlModel
from ...lo.report.report_definition import ReportDefinition as ReportDefinition
from ...lo.report.report_engine import ReportEngine as ReportEngine
from ...lo.report.report_print_option import ReportPrintOption as ReportPrintOption
from ...lo.report.section import Section as Section
from ...lo.report.section_page_break import SectionPageBreak as SectionPageBreak
from ...lo.report.shape import Shape as Shape
from ...lo.report.x_fixed_line import XFixedLine as XFixedLine
from ...lo.report.x_fixed_text import XFixedText as XFixedText
from ...lo.report.x_format_condition import XFormatCondition as XFormatCondition
from ...lo.report.x_formatted_field import XFormattedField as XFormattedField
from ...lo.report.x_function import XFunction as XFunction
from ...lo.report.x_functions import XFunctions as XFunctions
from ...lo.report.x_functions_supplier import XFunctionsSupplier as XFunctionsSupplier
from ...lo.report.x_group import XGroup as XGroup
from ...lo.report.x_groups import XGroups as XGroups
from ...lo.report.x_image_control import XImageControl as XImageControl
from ...lo.report.x_report_component import XReportComponent as XReportComponent
from ...lo.report.x_report_control_format import XReportControlFormat as XReportControlFormat
from ...lo.report.x_report_control_model import XReportControlModel as XReportControlModel
from ...lo.report.x_report_definition import XReportDefinition as XReportDefinition
from ...lo.report.x_report_engine import XReportEngine as XReportEngine
from ...lo.report.x_section import XSection as XSection
from ...lo.report.x_shape import XShape as XShape
