# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.xml.sax.fast_parser import FastParser as FastParser
from ....lo.xml.sax.fast_token import FastToken as FastToken
from ....lo.xml.sax.fast_token_handler import FastTokenHandler as FastTokenHandler
from ....lo.xml.sax.input_source import InputSource as InputSource
from ....lo.xml.sax.parser import Parser as Parser
from ....lo.xml.sax.sax_exception import SAXException as SAXException
from ....lo.xml.sax.sax_invalid_character_exception import SAXInvalidCharacterException as SAXInvalidCharacterException
from ....lo.xml.sax.sax_parse_exception import SAXParseException as SAXParseException
from ....lo.xml.sax.writer import Writer as Writer
from ....lo.xml.sax.x_attribute_list import XAttributeList as XAttributeList
from ....lo.xml.sax.xdtd_handler import XDTDHandler as XDTDHandler
from ....lo.xml.sax.x_document_handler import XDocumentHandler as XDocumentHandler
from ....lo.xml.sax.x_entity_resolver import XEntityResolver as XEntityResolver
from ....lo.xml.sax.x_error_handler import XErrorHandler as XErrorHandler
from ....lo.xml.sax.x_extended_document_handler import XExtendedDocumentHandler as XExtendedDocumentHandler
from ....lo.xml.sax.x_fast_attribute_list import XFastAttributeList as XFastAttributeList
from ....lo.xml.sax.x_fast_context_handler import XFastContextHandler as XFastContextHandler
from ....lo.xml.sax.x_fast_document_handler import XFastDocumentHandler as XFastDocumentHandler
from ....lo.xml.sax.x_fast_namespace_handler import XFastNamespaceHandler as XFastNamespaceHandler
from ....lo.xml.sax.x_fast_parser import XFastParser as XFastParser
from ....lo.xml.sax.x_fast_sax_serializable import XFastSAXSerializable as XFastSAXSerializable
from ....lo.xml.sax.x_fast_token_handler import XFastTokenHandler as XFastTokenHandler
from ....lo.xml.sax.x_locator import XLocator as XLocator
from ....lo.xml.sax.x_parser import XParser as XParser
from ....lo.xml.sax.xsax_serializable import XSAXSerializable as XSAXSerializable
from ....lo.xml.sax.x_writer import XWriter as XWriter
