# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class VerbAttributes(metaclass=UnoConstMeta, type_name="com.sun.star.embed.VerbAttributes", name_space="com.sun.star.embed"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.embed.VerbAttributes``"""
        pass

    class VerbAttributesEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.embed.VerbAttributes", name_space="com.sun.star.embed"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.embed.VerbAttributes`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.embed import VerbAttributes as VerbAttributes
    else:
        # keep document generators happy
        from ...lo.embed.verb_attributes import VerbAttributes as VerbAttributes

    class VerbAttributesEnum(IntFlag):
        """
        Enum of Const Class VerbAttributes

        The constant set specifies possible attributes of a verb.
        """
        MS_VERBATTR_NEVERDIRTIES = VerbAttributes.MS_VERBATTR_NEVERDIRTIES
        """
        Execution of the verb with this attribute must not modify the object.
        """
        MS_VERBATTR_ONCONTAINERMENU = VerbAttributes.MS_VERBATTR_ONCONTAINERMENU
        """
        indicates that the verb should appear in the object's menu.
        """

__all__ = ['VerbAttributes', 'VerbAttributesEnum']
