# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.presentation.animation_effect import AnimationEffect as AnimationEffect
from ...lo.presentation.animation_speed import AnimationSpeed as AnimationSpeed
from ...lo.presentation.chart_shape import ChartShape as ChartShape
from ...lo.presentation.click_action import ClickAction as ClickAction
from ...lo.presentation.custom_presentation import CustomPresentation as CustomPresentation
from ...lo.presentation.custom_presentation_access import CustomPresentationAccess as CustomPresentationAccess
from ...lo.presentation.date_time_shape import DateTimeShape as DateTimeShape
from ...lo.presentation.document_settings import DocumentSettings as DocumentSettings
from ...lo.presentation.draw_page import DrawPage as DrawPage
from ...lo.presentation.effect_commands import EffectCommands as EffectCommands
from ...lo.presentation.effect_node_type import EffectNodeType as EffectNodeType
from ...lo.presentation.effect_preset_class import EffectPresetClass as EffectPresetClass
from ...lo.presentation.fade_effect import FadeEffect as FadeEffect
from ...lo.presentation.footer_shape import FooterShape as FooterShape
from ...lo.presentation.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
from ...lo.presentation.handout_shape import HandoutShape as HandoutShape
from ...lo.presentation.handout_view import HandoutView as HandoutView
from ...lo.presentation.header_shape import HeaderShape as HeaderShape
from ...lo.presentation.notes_shape import NotesShape as NotesShape
from ...lo.presentation.notes_view import NotesView as NotesView
from ...lo.presentation.ole2_shape import OLE2Shape as OLE2Shape
from ...lo.presentation.outline_view import OutlineView as OutlineView
from ...lo.presentation.outliner_shape import OutlinerShape as OutlinerShape
from ...lo.presentation.page_shape import PageShape as PageShape
from ...lo.presentation.paragraph_target import ParagraphTarget as ParagraphTarget
from ...lo.presentation.presentation import Presentation as Presentation
from ...lo.presentation.presentation2 import Presentation2 as Presentation2
from ...lo.presentation.presentation_document import PresentationDocument as PresentationDocument
from ...lo.presentation.presentation_range import PresentationRange as PresentationRange
from ...lo.presentation.presentation_view import PresentationView as PresentationView
from ...lo.presentation.preview_view import PreviewView as PreviewView
from ...lo.presentation.shape import Shape as Shape
from ...lo.presentation.shape_animation_sub_type import ShapeAnimationSubType as ShapeAnimationSubType
from ...lo.presentation.slide_number_shape import SlideNumberShape as SlideNumberShape
from ...lo.presentation.slide_show import SlideShow as SlideShow
from ...lo.presentation.slides_view import SlidesView as SlidesView
from ...lo.presentation.subtitle_shape import SubtitleShape as SubtitleShape
from ...lo.presentation.text_animation_type import TextAnimationType as TextAnimationType
from ...lo.presentation.title_text_shape import TitleTextShape as TitleTextShape
from ...lo.presentation.transition_factory import TransitionFactory as TransitionFactory
from ...lo.presentation.x_custom_presentation_supplier import XCustomPresentationSupplier as XCustomPresentationSupplier
from ...lo.presentation.x_handout_master_supplier import XHandoutMasterSupplier as XHandoutMasterSupplier
from ...lo.presentation.x_presentation import XPresentation as XPresentation
from ...lo.presentation.x_presentation2 import XPresentation2 as XPresentation2
from ...lo.presentation.x_presentation_page import XPresentationPage as XPresentationPage
from ...lo.presentation.x_presentation_supplier import XPresentationSupplier as XPresentationSupplier
from ...lo.presentation.x_shape_event_listener import XShapeEventListener as XShapeEventListener
from ...lo.presentation.x_slide_show import XSlideShow as XSlideShow
from ...lo.presentation.x_slide_show_controller import XSlideShowController as XSlideShowController
from ...lo.presentation.x_slide_show_listener import XSlideShowListener as XSlideShowListener
from ...lo.presentation.x_slide_show_view import XSlideShowView as XSlideShowView
from ...lo.presentation.x_transition import XTransition as XTransition
from ...lo.presentation.x_transition_factory import XTransitionFactory as XTransitionFactory
