# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.logging.console_handler import ConsoleHandler as ConsoleHandler
from ...lo.logging.csv_log_formatter import CsvLogFormatter as CsvLogFormatter
from ...lo.logging.file_handler import FileHandler as FileHandler
from ...lo.logging.log_level import LogLevel as LogLevel
from ...lo.logging.log_record import LogRecord as LogRecord
from ...lo.logging.logger_pool import LoggerPool as LoggerPool
from ...lo.logging.plain_text_formatter import PlainTextFormatter as PlainTextFormatter
from ...lo.logging.simple_text_formatter import SimpleTextFormatter as SimpleTextFormatter
from ...lo.logging.x_console_handler import XConsoleHandler as XConsoleHandler
from ...lo.logging.x_csv_log_formatter import XCsvLogFormatter as XCsvLogFormatter
from ...lo.logging.x_log_formatter import XLogFormatter as XLogFormatter
from ...lo.logging.x_log_handler import XLogHandler as XLogHandler
from ...lo.logging.x_logger import XLogger as XLogger
from ...lo.logging.x_logger_pool import XLoggerPool as XLoggerPool
