# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.control
from __future__ import annotations
from ...awt.uno_control_button import UnoControlButton as UnoControlButton_d5e30ce3
from ..x_approve_action_broadcaster import XApproveActionBroadcaster as XApproveActionBroadcaster_693d10b9

class CommandButton(UnoControlButton_d5e30ce3, XApproveActionBroadcaster_693d10b9):
    """
    Service Class

    describes a button control.
    
    The model of the control has to support the com.sun.star.form.component.CommandButton service.
    
    The control is clickable, the action taken upon clicking depends on the settings of the model the control belongs to.

    See Also:
        `API CommandButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1CommandButton.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.control'
    __ooo_full_ns__: str = 'com.sun.star.form.control.CommandButton'
    __ooo_type_name__: str = 'service'


__all__ = ['CommandButton']

