# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.registry.cannot_register_implementation_exception import CannotRegisterImplementationException as CannotRegisterImplementationException
from ...lo.registry.default_registry import DefaultRegistry as DefaultRegistry
from ...lo.registry.implementation_registration import ImplementationRegistration as ImplementationRegistration
from ...lo.registry.invalid_registry_exception import InvalidRegistryException as InvalidRegistryException
from ...lo.registry.invalid_value_exception import InvalidValueException as InvalidValueException
from ...lo.registry.merge_conflict_exception import MergeConflictException as MergeConflictException
from ...lo.registry.nested_registry import NestedRegistry as NestedRegistry
from ...lo.registry.registry_key_type import RegistryKeyType as RegistryKeyType
from ...lo.registry.registry_value_type import RegistryValueType as RegistryValueType
from ...lo.registry.simple_registry import SimpleRegistry as SimpleRegistry
from ...lo.registry.x_implementation_registration import XImplementationRegistration as XImplementationRegistration
from ...lo.registry.x_implementation_registration2 import XImplementationRegistration2 as XImplementationRegistration2
from ...lo.registry.x_registry_key import XRegistryKey as XRegistryKey
from ...lo.registry.x_simple_registry import XSimpleRegistry as XSimpleRegistry
