# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.text
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class HorizontalAdjust(Enum):
    """
    Enum Class


    See Also:
        `API HorizontalAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text.html#a8105146481666b39ebbd63a934576b6c>`_
    """
    __ooo_ns__: str = "com.sun.star.text"
    __ooo_full_ns__: str = "com.sun.star.text.HorizontalAdjust"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.text.HorizontalAdjust"

    CENTER = "CENTER"
    """
    the object is adjusted to the center.
    
    centric adjusted.
    """
    LEFT = "LEFT"
    """
    the object is left adjusted.
    
    text flows to the left side of the object.
    
    adjusted to the left.
    """
    RIGHT = "RIGHT"
    """
    the object is right adjusted.
    
    text flows to the right side of the object.
    
    adjusted to the right.
    """

__all__ = ["HorizontalAdjust"]

