# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.container.container_event import ContainerEvent as ContainerEvent
from ...lo.container.element_exist_exception import ElementExistException as ElementExistException
from ...lo.container.enumerable_map import EnumerableMap as EnumerableMap
from ...lo.container.no_such_element_exception import NoSuchElementException as NoSuchElementException
from ...lo.container.x_child import XChild as XChild
from ...lo.container.x_component_enumeration import XComponentEnumeration as XComponentEnumeration
from ...lo.container.x_component_enumeration_access import XComponentEnumerationAccess as XComponentEnumerationAccess
from ...lo.container.x_container import XContainer as XContainer
from ...lo.container.x_container_approve_broadcaster import XContainerApproveBroadcaster as XContainerApproveBroadcaster
from ...lo.container.x_container_approve_listener import XContainerApproveListener as XContainerApproveListener
from ...lo.container.x_container_listener import XContainerListener as XContainerListener
from ...lo.container.x_container_query import XContainerQuery as XContainerQuery
from ...lo.container.x_content_enumeration_access import XContentEnumerationAccess as XContentEnumerationAccess
from ...lo.container.x_element_access import XElementAccess as XElementAccess
from ...lo.container.x_enumerable_map import XEnumerableMap as XEnumerableMap
from ...lo.container.x_enumeration import XEnumeration as XEnumeration
from ...lo.container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess
from ...lo.container.x_hierarchical_name import XHierarchicalName as XHierarchicalName
from ...lo.container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess
from ...lo.container.x_hierarchical_name_container import XHierarchicalNameContainer as XHierarchicalNameContainer
from ...lo.container.x_hierarchical_name_replace import XHierarchicalNameReplace as XHierarchicalNameReplace
from ...lo.container.x_identifier_access import XIdentifierAccess as XIdentifierAccess
from ...lo.container.x_identifier_container import XIdentifierContainer as XIdentifierContainer
from ...lo.container.x_identifier_replace import XIdentifierReplace as XIdentifierReplace
from ...lo.container.x_implicit_id_access import XImplicitIDAccess as XImplicitIDAccess
from ...lo.container.x_implicit_id_container import XImplicitIDContainer as XImplicitIDContainer
from ...lo.container.x_implicit_id_replace import XImplicitIDReplace as XImplicitIDReplace
from ...lo.container.x_index_access import XIndexAccess as XIndexAccess
from ...lo.container.x_index_container import XIndexContainer as XIndexContainer
from ...lo.container.x_index_replace import XIndexReplace as XIndexReplace
from ...lo.container.x_map import XMap as XMap
from ...lo.container.x_name_access import XNameAccess as XNameAccess
from ...lo.container.x_name_container import XNameContainer as XNameContainer
from ...lo.container.x_name_replace import XNameReplace as XNameReplace
from ...lo.container.x_named import XNamed as XNamed
from ...lo.container.x_set import XSet as XSet
from ...lo.container.x_string_key_map import XStringKeyMap as XStringKeyMap
from ...lo.container.x_unique_id_access import XUniqueIDAccess as XUniqueIDAccess
