# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs


class ExtendedFilePickerElementIds(object):
    """
    Const Class

    These constants are used to specify extended controls of a FilePicker dialog. A FilePicker service may be initialized so that it has additional controls extending the set of common controls a FilePicker usually supports.
    
    **since**
    
        LibreOffice 6.0

    See Also:
        `API ExtendedFilePickerElementIds <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExtendedFilePickerElementIds.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.ExtendedFilePickerElementIds'
    __ooo_type_name__: str = 'const'

    CHECKBOX_AUTOEXTENSION = 100
    CHECKBOX_PASSWORD = 101
    CHECKBOX_FILTEROPTIONS = 102
    CHECKBOX_READONLY = 103
    CHECKBOX_LINK = 104
    CHECKBOX_PREVIEW = 105
    PUSHBUTTON_PLAY = 106
    LISTBOX_VERSION = 107
    LISTBOX_TEMPLATE = 108
    LISTBOX_IMAGE_TEMPLATE = 109
    CHECKBOX_SELECTION = 110
    LISTBOX_VERSION_LABEL = 207
    LISTBOX_TEMPLATE_LABEL = 208
    LISTBOX_IMAGE_TEMPLATE_LABEL = 209
    LISTBOX_FILTER_SELECTOR = 210
    CHECKBOX_GPGENCRYPTION = 211
    LISTBOX_IMAGE_ANCHOR = 212
    LISTBOX_IMAGE_ANCHOR_LABEL = 213

__all__ = ['ExtendedFilePickerElementIds']
