# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTemplateInstance(XInterface_8f010a43):
    """
    is implemented by objects that are instances of a named template to provide information about the template.
    
    Template names are similar to service names, but apply to structure and content, rather than to type.
    
    Often a template description can be retrieved from a repository and then be interpreted by a factory object. Templates provide a means to build new kinds of objects dynamically.

    See Also:
        `API XTemplateInstance <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1XTemplateInstance.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration'
    __ooo_full_ns__: str = 'com.sun.star.configuration.XTemplateInstance'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.XTemplateInstance'

    @abstractmethod
    def getTemplateName(self) -> str:
        """
        retrieves the name of the template
        """
        ...

__all__ = ['XTemplateInstance']


