# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.view
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .print_job_event import PrintJobEvent as PrintJobEvent_bcd60bed

class XPrintJobListener(XEventListener_c7230c4a):
    """
    receives events about print job progress.
    
    XPrintJobListener can be registered to XPrintJobBroadcaster. Then, the client object will be notified when a new print job starts or its state changes.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XPrintJobListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XPrintJobListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XPrintJobListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XPrintJobListener'

    @abstractmethod
    def printJobEvent(self, Event: PrintJobEvent_bcd60bed) -> None:
        """
        informs the user about the creation or the progress of a PrintJob
        """
        ...

__all__ = ['XPrintJobListener']


