# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt


class FontWidth(object):
    """
    Const Class

    These values are used to specify the width of the characters of a font.
    
    They may be expanded in future versions.

    See Also:
        `API FontWidth <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontWidth.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.FontWidth'
    __ooo_type_name__: str = 'const'

    DONTKNOW = 0.0
    """
    The width of the font is not specified/known.
    """
    ULTRACONDENSED = 50.0
    """
    The width of the font is condensed to 50%.
    """
    EXTRACONDENSED = 60.0
    """
    The width of the font is condensed to 60%.
    """
    CONDENSED = 75.0
    """
    The width of the font is condensed to 75%.
    """
    SEMICONDENSED = 90.0
    """
    The width of the font is condensed to 90%.
    """
    NORMAL = 100.0
    """
    The width of the font is normal.
    """
    SEMIEXPANDED = 110.0
    """
    The width of the font is expanded to 110%.
    """
    EXPANDED = 150.0
    """
    The width of the font is expanded to 150%.
    """
    EXTRAEXPANDED = 175.0
    """
    The width of the font is expanded to 175%.
    """
    ULTRAEXPANDED = 200.0
    """
    The width of the font is expanded to 200%.
    """

__all__ = ['FontWidth']
