# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.linguistic2.conversion_dictionary import ConversionDictionary as ConversionDictionary
from ...lo.linguistic2.conversion_dictionary_list import ConversionDictionaryList as ConversionDictionaryList
from ...lo.linguistic2.conversion_dictionary_type import ConversionDictionaryType as ConversionDictionaryType
from ...lo.linguistic2.conversion_direction import ConversionDirection as ConversionDirection
from ...lo.linguistic2.conversion_property_type import ConversionPropertyType as ConversionPropertyType
from ...lo.linguistic2.dictionary import Dictionary as Dictionary
from ...lo.linguistic2.dictionary_event import DictionaryEvent as DictionaryEvent
from ...lo.linguistic2.dictionary_event_flags import DictionaryEventFlags as DictionaryEventFlags
from ...lo.linguistic2.dictionary_list import DictionaryList as DictionaryList
from ...lo.linguistic2.dictionary_list_event import DictionaryListEvent as DictionaryListEvent
from ...lo.linguistic2.dictionary_list_event_flags import DictionaryListEventFlags as DictionaryListEventFlags
from ...lo.linguistic2.dictionary_type import DictionaryType as DictionaryType
from ...lo.linguistic2.hangul_hanja_conversion_dictionary import HangulHanjaConversionDictionary as HangulHanjaConversionDictionary
from ...lo.linguistic2.hyphenator import Hyphenator as Hyphenator
from ...lo.linguistic2.language_guessing import LanguageGuessing as LanguageGuessing
from ...lo.linguistic2.lingu_properties import LinguProperties as LinguProperties
from ...lo.linguistic2.lingu_service_event import LinguServiceEvent as LinguServiceEvent
from ...lo.linguistic2.lingu_service_event_flags import LinguServiceEventFlags as LinguServiceEventFlags
from ...lo.linguistic2.lingu_service_manager import LinguServiceManager as LinguServiceManager
from ...lo.linguistic2.number_text import NumberText as NumberText
from ...lo.linguistic2.proofreader import Proofreader as Proofreader
from ...lo.linguistic2.proofreading_iterator import ProofreadingIterator as ProofreadingIterator
from ...lo.linguistic2.proofreading_result import ProofreadingResult as ProofreadingResult
from ...lo.linguistic2.single_proofreading_error import SingleProofreadingError as SingleProofreadingError
from ...lo.linguistic2.spell_checker import SpellChecker as SpellChecker
from ...lo.linguistic2.spell_failure import SpellFailure as SpellFailure
from ...lo.linguistic2.thesaurus import Thesaurus as Thesaurus
from ...lo.linguistic2.x_available_locales import XAvailableLocales as XAvailableLocales
from ...lo.linguistic2.x_conversion_dictionary import XConversionDictionary as XConversionDictionary
from ...lo.linguistic2.x_conversion_dictionary_list import XConversionDictionaryList as XConversionDictionaryList
from ...lo.linguistic2.x_conversion_property_type import XConversionPropertyType as XConversionPropertyType
from ...lo.linguistic2.x_dictionary import XDictionary as XDictionary
from ...lo.linguistic2.x_dictionary1 import XDictionary1 as XDictionary1
from ...lo.linguistic2.x_dictionary_entry import XDictionaryEntry as XDictionaryEntry
from ...lo.linguistic2.x_dictionary_event_listener import XDictionaryEventListener as XDictionaryEventListener
from ...lo.linguistic2.x_dictionary_list import XDictionaryList as XDictionaryList
from ...lo.linguistic2.x_dictionary_list_event_listener import XDictionaryListEventListener as XDictionaryListEventListener
from ...lo.linguistic2.x_hyphenated_word import XHyphenatedWord as XHyphenatedWord
from ...lo.linguistic2.x_hyphenator import XHyphenator as XHyphenator
from ...lo.linguistic2.x_language_guessing import XLanguageGuessing as XLanguageGuessing
from ...lo.linguistic2.x_lingu_properties import XLinguProperties as XLinguProperties
from ...lo.linguistic2.x_lingu_service_event_broadcaster import XLinguServiceEventBroadcaster as XLinguServiceEventBroadcaster
from ...lo.linguistic2.x_lingu_service_event_listener import XLinguServiceEventListener as XLinguServiceEventListener
from ...lo.linguistic2.x_lingu_service_manager import XLinguServiceManager as XLinguServiceManager
from ...lo.linguistic2.x_lingu_service_manager2 import XLinguServiceManager2 as XLinguServiceManager2
from ...lo.linguistic2.x_meaning import XMeaning as XMeaning
from ...lo.linguistic2.x_number_text import XNumberText as XNumberText
from ...lo.linguistic2.x_possible_hyphens import XPossibleHyphens as XPossibleHyphens
from ...lo.linguistic2.x_proofreader import XProofreader as XProofreader
from ...lo.linguistic2.x_proofreading_iterator import XProofreadingIterator as XProofreadingIterator
from ...lo.linguistic2.x_searchable_dictionary import XSearchableDictionary as XSearchableDictionary
from ...lo.linguistic2.x_searchable_dictionary_list import XSearchableDictionaryList as XSearchableDictionaryList
from ...lo.linguistic2.x_set_spell_alternatives import XSetSpellAlternatives as XSetSpellAlternatives
from ...lo.linguistic2.x_spell_alternatives import XSpellAlternatives as XSpellAlternatives
from ...lo.linguistic2.x_spell_checker import XSpellChecker as XSpellChecker
from ...lo.linguistic2.x_spell_checker1 import XSpellChecker1 as XSpellChecker1
from ...lo.linguistic2.x_supported_languages import XSupportedLanguages as XSupportedLanguages
from ...lo.linguistic2.x_supported_locales import XSupportedLocales as XSupportedLocales
from ...lo.linguistic2.x_thesaurus import XThesaurus as XThesaurus
