# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.style.break_type import BreakType as BreakType
from ...lo.style.case_map import CaseMap as CaseMap
from ...lo.style.cell_style import CellStyle as CellStyle
from ...lo.style.character_properties import CharacterProperties as CharacterProperties
from ...lo.style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian
from ...lo.style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex
from ...lo.style.character_style import CharacterStyle as CharacterStyle
from ...lo.style.drop_cap_format import DropCapFormat as DropCapFormat
from ...lo.style.footnote_line_style import FootnoteLineStyle as FootnoteLineStyle
from ...lo.style.graphic_location import GraphicLocation as GraphicLocation
from ...lo.style.horizontal_alignment import HorizontalAlignment as HorizontalAlignment
from ...lo.style.line_number_position import LineNumberPosition as LineNumberPosition
from ...lo.style.line_spacing import LineSpacing as LineSpacing
from ...lo.style.line_spacing_mode import LineSpacingMode as LineSpacingMode
from ...lo.style.numbering_alignment import NumberingAlignment as NumberingAlignment
from ...lo.style.numbering_level import NumberingLevel as NumberingLevel
from ...lo.style.numbering_rule import NumberingRule as NumberingRule
from ...lo.style.numbering_type import NumberingType as NumberingType
from ...lo.style.page_properties import PageProperties as PageProperties
from ...lo.style.page_style import PageStyle as PageStyle
from ...lo.style.page_style_layout import PageStyleLayout as PageStyleLayout
from ...lo.style.paragraph_adjust import ParagraphAdjust as ParagraphAdjust
from ...lo.style.paragraph_properties import ParagraphProperties as ParagraphProperties
from ...lo.style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian
from ...lo.style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex
from ...lo.style.paragraph_style import ParagraphStyle as ParagraphStyle
from ...lo.style.paragraph_style_category import ParagraphStyleCategory as ParagraphStyleCategory
from ...lo.style.style import Style as Style
from ...lo.style.style_families import StyleFamilies as StyleFamilies
from ...lo.style.style_family import StyleFamily as StyleFamily
from ...lo.style.tab_align import TabAlign as TabAlign
from ...lo.style.tab_stop import TabStop as TabStop
from ...lo.style.vertical_alignment import VerticalAlignment as VerticalAlignment
from ...lo.style.x_auto_style import XAutoStyle as XAutoStyle
from ...lo.style.x_auto_style_family import XAutoStyleFamily as XAutoStyleFamily
from ...lo.style.x_auto_styles import XAutoStyles as XAutoStyles
from ...lo.style.x_auto_styles_supplier import XAutoStylesSupplier as XAutoStylesSupplier
from ...lo.style.x_defaults_supplier import XDefaultsSupplier as XDefaultsSupplier
from ...lo.style.x_style import XStyle as XStyle
from ...lo.style.x_style_families_supplier import XStyleFamiliesSupplier as XStyleFamiliesSupplier
from ...lo.style.x_style_loader import XStyleLoader as XStyleLoader
from ...lo.style.x_style_loader2 import XStyleLoader2 as XStyleLoader2
from ...lo.style.x_style_supplier import XStyleSupplier as XStyleSupplier
