# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.awt.tab.tab_page_activated_event import TabPageActivatedEvent as TabPageActivatedEvent
from ....lo.awt.tab.uno_control_tab_page import UnoControlTabPage as UnoControlTabPage
from ....lo.awt.tab.uno_control_tab_page_container import UnoControlTabPageContainer as UnoControlTabPageContainer
from ....lo.awt.tab.uno_control_tab_page_container_model import UnoControlTabPageContainerModel as UnoControlTabPageContainerModel
from ....lo.awt.tab.uno_control_tab_page_model import UnoControlTabPageModel as UnoControlTabPageModel
from ....lo.awt.tab.x_tab_page import XTabPage as XTabPage
from ....lo.awt.tab.x_tab_page_container import XTabPageContainer as XTabPageContainer
from ....lo.awt.tab.x_tab_page_container_listener import XTabPageContainerListener as XTabPageContainerListener
from ....lo.awt.tab.x_tab_page_container_model import XTabPageContainerModel as XTabPageContainerModel
from ....lo.awt.tab.x_tab_page_model import XTabPageModel as XTabPageModel
