# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from abc import abstractproperty
from .x3_d_default_setter import X3DDefaultSetter as X3DDefaultSetter_e9630d25
from .x3_d_display import X3DDisplay as X3DDisplay_a1650abf

class Dim3DDiagram(X3DDefaultSetter_e9630d25, X3DDisplay_a1650abf):
    """
    Service Class

    is a service for diagrams that support the capability to render themselves as three-dimensional diagrams as well as two-dimensional ones.

    See Also:
        `API Dim3DDiagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1Dim3DDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.Dim3DDiagram'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Dim3D(self) -> bool:
        """
        If set to TRUE, the chart becomes a three-dimensional chart.
        
        Otherwise it is two-dimensional.
        """
        ...

    @abstractproperty
    def Perspective(self) -> int:
        """
        Perspective of 3D charts ( [0,100] ).
        """
        ...

    @abstractproperty
    def RotationHorizontal(self) -> int:
        """
        Horizontal rotation of 3D charts in degrees ( ]-180,180] ).
        """
        ...

    @abstractproperty
    def RotationVertical(self) -> int:
        """
        Vertical rotation of 3D charts in degrees ( ]-180,180] ).
        """
        ...


__all__ = ['Dim3DDiagram']

