# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
from .x_number_text import XNumberText as XNumberText_feeb0ddb

class NumberText(XNumberText_feeb0ddb):
    """
    Service Class

    provides converter to spell out numbers and money amounts
    
    An implementation of this service will receive text and has to spell out as cardinal, ordinal, ordinal indicator or money amounts.
    
    An implementation of this service is not limited to number to number conversion at all. It might also support other linguistic functions of a given language, for example, spelling out years, gender and formal variants or complex affixation of number names, or article selection.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API NumberText <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1linguistic2_1_1NumberText.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.NumberText'
    __ooo_type_name__: str = 'service'


__all__ = ['NumberText']

