# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d

class Invocation(XSingleServiceFactory_27210f0d):
    """
    Service Class

    factory service that allows construction of Invocation objects.
    
    Invoke createInstanceWithArguments() of XSingleServiceFactory to create an Invocation adapter for the passed object (Invoking createInstance() will fail).
    
    The adapter has to support com.sun.star.script.XInvocation. The adapter may also support com.sun.star.script.XInvocation2.

    See Also:
        `API Invocation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1script_1_1Invocation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.Invocation'
    __ooo_type_name__: str = 'service'


__all__ = ['Invocation']

