# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0

class HelpContentProvider(XContentProvider_d4150cc0):
    """
    Service Class

    The Help Content Provider (HCP) implements a ContentProvider for the UniversalContentBroker (UCB).
    
    The served contents enable access to the help contents and to the search engine.

    See Also:
        `API HelpContentProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1HelpContentProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.HelpContentProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['HelpContentProvider']

