# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.drawing.framework.anchor_binding_mode import AnchorBindingMode as AnchorBindingMode
from ....lo.drawing.framework.basic_pane_factory import BasicPaneFactory as BasicPaneFactory
from ....lo.drawing.framework.basic_tool_bar_factory import BasicToolBarFactory as BasicToolBarFactory
from ....lo.drawing.framework.basic_view_factory import BasicViewFactory as BasicViewFactory
from ....lo.drawing.framework.border_type import BorderType as BorderType
from ....lo.drawing.framework.configuration import Configuration as Configuration
from ....lo.drawing.framework.configuration_change_event import ConfigurationChangeEvent as ConfigurationChangeEvent
from ....lo.drawing.framework.configuration_controller import ConfigurationController as ConfigurationController
from ....lo.drawing.framework.module_controller import ModuleController as ModuleController
from ....lo.drawing.framework.resource_activation_mode import ResourceActivationMode as ResourceActivationMode
from ....lo.drawing.framework.resource_id import ResourceId as ResourceId
from ....lo.drawing.framework.tab_bar_button import TabBarButton as TabBarButton
from ....lo.drawing.framework.x_configuration import XConfiguration as XConfiguration
from ....lo.drawing.framework.x_configuration_change_listener import XConfigurationChangeListener as XConfigurationChangeListener
from ....lo.drawing.framework.x_configuration_change_request import XConfigurationChangeRequest as XConfigurationChangeRequest
from ....lo.drawing.framework.x_configuration_controller import XConfigurationController as XConfigurationController
from ....lo.drawing.framework.x_configuration_controller_broadcaster import XConfigurationControllerBroadcaster as XConfigurationControllerBroadcaster
from ....lo.drawing.framework.x_configuration_controller_request_queue import XConfigurationControllerRequestQueue as XConfigurationControllerRequestQueue
from ....lo.drawing.framework.x_controller_manager import XControllerManager as XControllerManager
from ....lo.drawing.framework.x_module_controller import XModuleController as XModuleController
from ....lo.drawing.framework.x_pane import XPane as XPane
from ....lo.drawing.framework.x_pane2 import XPane2 as XPane2
from ....lo.drawing.framework.x_pane_border_painter import XPaneBorderPainter as XPaneBorderPainter
from ....lo.drawing.framework.x_relocatable_resource import XRelocatableResource as XRelocatableResource
from ....lo.drawing.framework.x_resource import XResource as XResource
from ....lo.drawing.framework.x_resource_factory import XResourceFactory as XResourceFactory
from ....lo.drawing.framework.x_resource_factory_manager import XResourceFactoryManager as XResourceFactoryManager
from ....lo.drawing.framework.x_resource_id import XResourceId as XResourceId
from ....lo.drawing.framework.x_tab_bar import XTabBar as XTabBar
from ....lo.drawing.framework.x_tool_bar import XToolBar as XToolBar
from ....lo.drawing.framework.x_view import XView as XView
