# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TolerantPropertySetResultType(metaclass=UnoConstMeta, type_name="com.sun.star.beans.TolerantPropertySetResultType", name_space="com.sun.star.beans"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.beans.TolerantPropertySetResultType``"""
        pass

    class TolerantPropertySetResultTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.beans.TolerantPropertySetResultType", name_space="com.sun.star.beans"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.beans.TolerantPropertySetResultType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.beans import TolerantPropertySetResultType as TolerantPropertySetResultType
    else:
        # keep document generators happy
        from ...lo.beans.tolerant_property_set_result_type import TolerantPropertySetResultType as TolerantPropertySetResultType

    class TolerantPropertySetResultTypeEnum(IntEnum):
        """
        Enum of Const Class TolerantPropertySetResultType

        specifies the possible failure types when using the com.sun.star.beans.XTolerantMultiPropertySet interface.
        
        It usually matches one of the exception types that may occur when using the com.sun.star.beans.XPropertySet or com.sun.star.beans.XMultiPropertySet interfaces.
        """
        SUCCESS = TolerantPropertySetResultType.SUCCESS
        """
        the property has been successfully set or retrieved.
        """
        UNKNOWN_PROPERTY = TolerantPropertySetResultType.UNKNOWN_PROPERTY
        """
        the property is not available.
        
        For example if a com.sun.star.beans.UnknownPropertyException was caught.
        """
        ILLEGAL_ARGUMENT = TolerantPropertySetResultType.ILLEGAL_ARGUMENT
        """
        the value used with the property is not valid.
        
        For example if a com.sun.star.lang.IllegalArgumentException was caught.
        """
        PROPERTY_VETO = TolerantPropertySetResultType.PROPERTY_VETO
        """
        the property could not be changed at that time.
        
        For example if a com.sun.star.beans.PropertyVetoException was caught.
        """
        WRAPPED_TARGET = TolerantPropertySetResultType.WRAPPED_TARGET
        """
        a com.sun.star.lang.WrappedTargetException did occur.
        """
        UNKNOWN_FAILURE = TolerantPropertySetResultType.UNKNOWN_FAILURE
        """
        the operation failed and the reason is not known.
        """

__all__ = ['TolerantPropertySetResultType', 'TolerantPropertySetResultTypeEnum']
