# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.packages
from __future__ import annotations
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_named import XNamed as XNamed_a6520b08
from ..io.x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3

class PackageStream(XPropertySet_bc180bfa, XChild_a6390b07, XNamed_a6520b08, XActiveDataSink_b8d00ba3):
    """
    Service Class

    This service represents a stream contained within a Package.
    
    Instances of this class can only be constructed by the implementation of the Package service.

    See Also:
        `API PackageStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1packages_1_1PackageStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.packages'
    __ooo_full_ns__: str = 'com.sun.star.packages.PackageStream'
    __ooo_type_name__: str = 'service'


__all__ = ['PackageStream']

