# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_control import XControl as XControl_7a9c098d

class XControlContainer(XInterface_8f010a43):
    """
    Provides access to the controls within an UnoControlContainer.

    See Also:
        `API XControlContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XControlContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XControlContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XControlContainer'

    @abstractmethod
    def addControl(self, Name: str, Control: XControl_7a9c098d) -> None:
        """
        adds the given control with the specified name to the container.
        """
        ...
    @abstractmethod
    def getControl(self, aName: str) -> XControl_7a9c098d:
        """
        returns the control with the specified name.
        """
        ...
    @abstractmethod
    def getControls(self) -> typing.Tuple[XControl_7a9c098d, ...]:
        """
        returns all controls.
        """
        ...
    @abstractmethod
    def removeControl(self, Control: XControl_7a9c098d) -> None:
        """
        removes the given control from the container.
        """
        ...
    @abstractmethod
    def setStatusText(self, StatusText: str) -> None:
        """
        sets the status text in the status bar of the container.
        """
        ...

__all__ = ['XControlContainer']


