# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from .....lo.text.textfield.docinfo.change_author import ChangeAuthor as ChangeAuthor
from .....lo.text.textfield.docinfo.change_date_time import ChangeDateTime as ChangeDateTime
from .....lo.text.textfield.docinfo.create_author import CreateAuthor as CreateAuthor
from .....lo.text.textfield.docinfo.create_date_time import CreateDateTime as CreateDateTime
from .....lo.text.textfield.docinfo.custom import Custom as Custom
from .....lo.text.textfield.docinfo.description import Description as Description
from .....lo.text.textfield.docinfo.edit_time import EditTime as EditTime
from .....lo.text.textfield.docinfo.keywords import Keywords as Keywords
from .....lo.text.textfield.docinfo.print_author import PrintAuthor as PrintAuthor
from .....lo.text.textfield.docinfo.print_date_time import PrintDateTime as PrintDateTime
from .....lo.text.textfield.docinfo.revision import Revision as Revision
from .....lo.text.textfield.docinfo.subject import Subject as Subject
from .....lo.text.textfield.docinfo.title import Title as Title
