# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..task.x_interaction_handler2 import XInteractionHandler2 as XInteractionHandler2_1a7b0e83

class DatabaseInteractionHandler(XInteractionHandler2_1a7b0e83):
    """
    Service Class

    describes a service which is able to handle database-related interactions.
    
    Usually, you will not instantiate this service directly. Instead, you'll instantiate a generic com.sun.star.task.InteractionHandler service, and pass it your request. Based on configuration data, this implementation will decide where to forward the request to.
    
    By default, the DatabaseInteractionHandler feels responsible (as per configuration) for the following interaction types:

    See Also:
        `API DatabaseInteractionHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseInteractionHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseInteractionHandler'
    __ooo_type_name__: str = 'service'


__all__ = ['DatabaseInteractionHandler']

