# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..lang.x_localizable import XLocalizable as XLocalizable_aee00b64
from ..util.x_localized_aliases import XLocalizedAliases as XLocalizedAliases_ef7c0d77

class DatabaseAccessContext(XEnumerationAccess_4bac0ffc, XNameAccess_e2ab0cf6, XLocalizable_aee00b64, XLocalizedAliases_ef7c0d77):
    """
    Service Class

    is the context for data access beans.
    
    It allows to register aliases for database access beans. It is possible to have different aliases for different locales.
    
    A DatabaseContext stores an alias for the URL of a database access component for a given locale. It is also allowed to work with a default locale. This is useful in connection with Enumeration or NameAccess to the context. In common use, the default language is set during the initialization of the component.
    
    The service also provides a default handling for locales, where an alias isn't set. The first time an alias is registered for a programmatic name, the alias becomes the default for all other known locales.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DatabaseAccessContext <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccessContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseAccessContext'
    __ooo_type_name__: str = 'service'


__all__ = ['DatabaseAccessContext']

