# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb


class RowChangeAction(object):
    """
    Const Class

    determines the type of change which is going to be performed.

    See Also:
        `API RowChangeAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1RowChangeAction.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.RowChangeAction'
    __ooo_type_name__: str = 'const'

    INSERT = 1
    """
    indicates that an insert will be performed.
    """
    UPDATE = 2
    """
    indicates that an update will be performed.
    """
    DELETE = 3
    """
    indicates that a delete will be performed.
    """

__all__ = ['RowChangeAction']
