# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
from .x_uri_scheme_parser import XUriSchemeParser as XUriSchemeParser_d3fd0ca2

class UriSchemeParser_vndDOTsunDOTstarDOTscript(XUriSchemeParser_d3fd0ca2):
    """
    Service Class

    parses textual representations of absolute “vnd.sun.star.script” URLs.
    
    The argument scheme of method com.sun.star.uri.XUriSchemeParser.parse() must always be equal to the string \"vnd.sun.star.script\", ignoring case. The objects returned by com.sun.star.uri.XUriSchemeParser.parse() implement com.sun.star.uri.XVndSunStarScriptUrlReference.
    
    This service is not intended to be instantiated directly by client code. Rather, it should be used indirectly through the com.sun.star.uri.UriReferenceFactory service.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UriSchemeParser_vndDOTsunDOTstarDOTscript <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1uri_1_1UriSchemeParser__vndDOTsunDOTstarDOTscript.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.UriSchemeParser_vndDOTsunDOTstarDOTscript'
    __ooo_type_name__: str = 'service'


__all__ = ['UriSchemeParser_vndDOTsunDOTstarDOTscript']

