# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.sdb.boolean_comparison_mode import BooleanComparisonMode as BooleanComparisonMode
from ...lo.sdb.callable_statement import CallableStatement as CallableStatement
from ...lo.sdb.column import Column as Column
from ...lo.sdb.column_descriptor_control import ColumnDescriptorControl as ColumnDescriptorControl
from ...lo.sdb.column_descriptor_control_model import ColumnDescriptorControlModel as ColumnDescriptorControlModel
from ...lo.sdb.column_settings import ColumnSettings as ColumnSettings
from ...lo.sdb.command_definition import CommandDefinition as CommandDefinition
from ...lo.sdb.command_type import CommandType as CommandType
from ...lo.sdb.connection import Connection as Connection
from ...lo.sdb.content_loader import ContentLoader as ContentLoader
from ...lo.sdb.data_access_descriptor import DataAccessDescriptor as DataAccessDescriptor
from ...lo.sdb.data_access_descriptor_factory import DataAccessDescriptorFactory as DataAccessDescriptorFactory
from ...lo.sdb.data_column import DataColumn as DataColumn
from ...lo.sdb.data_settings import DataSettings as DataSettings
from ...lo.sdb.data_source import DataSource as DataSource
from ...lo.sdb.data_source_browser import DataSourceBrowser as DataSourceBrowser
from ...lo.sdb.database_access import DatabaseAccess as DatabaseAccess
from ...lo.sdb.database_access_connection import DatabaseAccessConnection as DatabaseAccessConnection
from ...lo.sdb.database_access_context import DatabaseAccessContext as DatabaseAccessContext
from ...lo.sdb.database_access_data_source import DatabaseAccessDataSource as DatabaseAccessDataSource
from ...lo.sdb.database_context import DatabaseContext as DatabaseContext
from ...lo.sdb.database_document import DatabaseDocument as DatabaseDocument
from ...lo.sdb.database_environment import DatabaseEnvironment as DatabaseEnvironment
from ...lo.sdb.database_interaction_handler import DatabaseInteractionHandler as DatabaseInteractionHandler
from ...lo.sdb.database_registration_event import DatabaseRegistrationEvent as DatabaseRegistrationEvent
from ...lo.sdb.datasource_administration_dialog import DatasourceAdministrationDialog as DatasourceAdministrationDialog
from ...lo.sdb.definition_container import DefinitionContainer as DefinitionContainer
from ...lo.sdb.definition_content import DefinitionContent as DefinitionContent
from ...lo.sdb.document import Document as Document
from ...lo.sdb.document_container import DocumentContainer as DocumentContainer
from ...lo.sdb.document_data_source import DocumentDataSource as DocumentDataSource
from ...lo.sdb.document_definition import DocumentDefinition as DocumentDefinition
from ...lo.sdb.document_save_request import DocumentSaveRequest as DocumentSaveRequest
from ...lo.sdb.error_condition import ErrorCondition as ErrorCondition
from ...lo.sdb.error_message_dialog import ErrorMessageDialog as ErrorMessageDialog
from ...lo.sdb.filter_dialog import FilterDialog as FilterDialog
from ...lo.sdb.forms import Forms as Forms
from ...lo.sdb.interaction_handler import InteractionHandler as InteractionHandler
from ...lo.sdb.office_database_document import OfficeDatabaseDocument as OfficeDatabaseDocument
from ...lo.sdb.order_column import OrderColumn as OrderColumn
from ...lo.sdb.order_dialog import OrderDialog as OrderDialog
from ...lo.sdb.parameters_request import ParametersRequest as ParametersRequest
from ...lo.sdb.prepared_statement import PreparedStatement as PreparedStatement
from ...lo.sdb.query import Query as Query
from ...lo.sdb.query_definition import QueryDefinition as QueryDefinition
from ...lo.sdb.query_descriptor import QueryDescriptor as QueryDescriptor
from ...lo.sdb.query_design import QueryDesign as QueryDesign
from ...lo.sdb.relation_design import RelationDesign as RelationDesign
from ...lo.sdb.report_design import ReportDesign as ReportDesign
from ...lo.sdb.reports import Reports as Reports
from ...lo.sdb.result_column import ResultColumn as ResultColumn
from ...lo.sdb.result_set import ResultSet as ResultSet
from ...lo.sdb.row_change_action import RowChangeAction as RowChangeAction
from ...lo.sdb.row_change_event import RowChangeEvent as RowChangeEvent
from ...lo.sdb.row_set import RowSet as RowSet
from ...lo.sdb.row_set_veto_exception import RowSetVetoException as RowSetVetoException
from ...lo.sdb.rows_change_event import RowsChangeEvent as RowsChangeEvent
from ...lo.sdb.sql_context import SQLContext as SQLContext
from ...lo.sdb.sql_error_event import SQLErrorEvent as SQLErrorEvent
from ...lo.sdb.sql_filter_operator import SQLFilterOperator as SQLFilterOperator
from ...lo.sdb.sql_query_composer import SQLQueryComposer as SQLQueryComposer
from ...lo.sdb.single_select_query_analyzer import SingleSelectQueryAnalyzer as SingleSelectQueryAnalyzer
from ...lo.sdb.single_select_query_composer import SingleSelectQueryComposer as SingleSelectQueryComposer
from ...lo.sdb.table import Table as Table
from ...lo.sdb.table_definition import TableDefinition as TableDefinition
from ...lo.sdb.table_descriptor import TableDescriptor as TableDescriptor
from ...lo.sdb.table_design import TableDesign as TableDesign
from ...lo.sdb.text_connection_settings import TextConnectionSettings as TextConnectionSettings
from ...lo.sdb.x_alter_query import XAlterQuery as XAlterQuery
from ...lo.sdb.x_bookmarks_supplier import XBookmarksSupplier as XBookmarksSupplier
from ...lo.sdb.x_column import XColumn as XColumn
from ...lo.sdb.x_column_update import XColumnUpdate as XColumnUpdate
from ...lo.sdb.x_command_preparation import XCommandPreparation as XCommandPreparation
from ...lo.sdb.x_completed_connection import XCompletedConnection as XCompletedConnection
from ...lo.sdb.x_completed_execution import XCompletedExecution as XCompletedExecution
from ...lo.sdb.x_data_access_descriptor_factory import XDataAccessDescriptorFactory as XDataAccessDescriptorFactory
from ...lo.sdb.x_database_access import XDatabaseAccess as XDatabaseAccess
from ...lo.sdb.x_database_access_listener import XDatabaseAccessListener as XDatabaseAccessListener
from ...lo.sdb.x_database_context import XDatabaseContext as XDatabaseContext
from ...lo.sdb.x_database_environment import XDatabaseEnvironment as XDatabaseEnvironment
from ...lo.sdb.x_database_registrations import XDatabaseRegistrations as XDatabaseRegistrations
from ...lo.sdb.x_database_registrations_listener import XDatabaseRegistrationsListener as XDatabaseRegistrationsListener
from ...lo.sdb.x_document_data_source import XDocumentDataSource as XDocumentDataSource
from ...lo.sdb.x_form_documents_supplier import XFormDocumentsSupplier as XFormDocumentsSupplier
from ...lo.sdb.x_interaction_document_save import XInteractionDocumentSave as XInteractionDocumentSave
from ...lo.sdb.x_interaction_supply_parameters import XInteractionSupplyParameters as XInteractionSupplyParameters
from ...lo.sdb.x_office_database_document import XOfficeDatabaseDocument as XOfficeDatabaseDocument
from ...lo.sdb.x_parameters_supplier import XParametersSupplier as XParametersSupplier
from ...lo.sdb.x_queries_supplier import XQueriesSupplier as XQueriesSupplier
from ...lo.sdb.x_query_definition import XQueryDefinition as XQueryDefinition
from ...lo.sdb.x_query_definitions_supplier import XQueryDefinitionsSupplier as XQueryDefinitionsSupplier
from ...lo.sdb.x_report_documents_supplier import XReportDocumentsSupplier as XReportDocumentsSupplier
from ...lo.sdb.x_result_set_access import XResultSetAccess as XResultSetAccess
from ...lo.sdb.x_row_set_approve_broadcaster import XRowSetApproveBroadcaster as XRowSetApproveBroadcaster
from ...lo.sdb.x_row_set_approve_listener import XRowSetApproveListener as XRowSetApproveListener
from ...lo.sdb.x_row_set_change_broadcaster import XRowSetChangeBroadcaster as XRowSetChangeBroadcaster
from ...lo.sdb.x_row_set_change_listener import XRowSetChangeListener as XRowSetChangeListener
from ...lo.sdb.x_row_set_supplier import XRowSetSupplier as XRowSetSupplier
from ...lo.sdb.x_rows_change_broadcaster import XRowsChangeBroadcaster as XRowsChangeBroadcaster
from ...lo.sdb.x_rows_change_listener import XRowsChangeListener as XRowsChangeListener
from ...lo.sdb.xsql_error_broadcaster import XSQLErrorBroadcaster as XSQLErrorBroadcaster
from ...lo.sdb.xsql_error_listener import XSQLErrorListener as XSQLErrorListener
from ...lo.sdb.xsql_query_composer import XSQLQueryComposer as XSQLQueryComposer
from ...lo.sdb.xsql_query_composer_factory import XSQLQueryComposerFactory as XSQLQueryComposerFactory
from ...lo.sdb.x_single_select_query_analyzer import XSingleSelectQueryAnalyzer as XSingleSelectQueryAnalyzer
from ...lo.sdb.x_single_select_query_composer import XSingleSelectQueryComposer as XSingleSelectQueryComposer
from ...lo.sdb.x_sub_document import XSubDocument as XSubDocument
from ...lo.sdb.x_text_connection_settings import XTextConnectionSettings as XTextConnectionSettings
