# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class reservedWords(object):
    """
    Const Class

    Offsets into the sequence of strings returned by XLocaleData.getReservedWord().

    See Also:
        `API reservedWords <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1reservedWords.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.reservedWords'
    __ooo_type_name__: str = 'const'

    TRUE_WORD = 0
    """
    \"true\"
    """
    FALSE_WORD = 1
    """
    \"false\"
    """
    QUARTER1_WORD = 2
    """
    \"1st quarter\"
    """
    QUARTER2_WORD = 3
    """
    \"2nd quarter\"
    """
    QUARTER3_WORD = 4
    """
    \"3rd quarter\"
    """
    QUARTER4_WORD = 5
    """
    \"4th quarter\"
    """
    ABOVE_WORD = 6
    """
    \"above\"
    """
    BELOW_WORD = 7
    """
    \"below\"
    """
    QUARTER1_ABBREVIATION = 8
    """
    \"Q1\"
    """
    QUARTER2_ABBREVIATION = 9
    """
    \"Q2\"
    """
    QUARTER3_ABBREVIATION = 10
    """
    \"Q3\"
    """
    QUARTER4_ABBREVIATION = 11
    """
    \"Q4\"
    """
    COUNT = 12
    """
    Yes, this must be the count of known reserved words and one more than the maximum number used above! Count of known reserved words.
    """

__all__ = ['reservedWords']
