# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.sdbc.batch_update_exception import BatchUpdateException as BatchUpdateException
from ...lo.sdbc.best_row_scope import BestRowScope as BestRowScope
from ...lo.sdbc.best_row_type import BestRowType as BestRowType
from ...lo.sdbc.callable_statement import CallableStatement as CallableStatement
from ...lo.sdbc.change_action import ChangeAction as ChangeAction
from ...lo.sdbc.change_event import ChangeEvent as ChangeEvent
from ...lo.sdbc.column_search import ColumnSearch as ColumnSearch
from ...lo.sdbc.column_type import ColumnType as ColumnType
from ...lo.sdbc.column_value import ColumnValue as ColumnValue
from ...lo.sdbc.connection import Connection as Connection
from ...lo.sdbc.connection_pool import ConnectionPool as ConnectionPool
from ...lo.sdbc.connection_properties import ConnectionProperties as ConnectionProperties
from ...lo.sdbc.dbase_connection_properties import DBASEConnectionProperties as DBASEConnectionProperties
from ...lo.sdbc.data_truncation import DataTruncation as DataTruncation
from ...lo.sdbc.data_type import DataType as DataType
from ...lo.sdbc.deferrability import Deferrability as Deferrability
from ...lo.sdbc.driver import Driver as Driver
from ...lo.sdbc.driver_manager import DriverManager as DriverManager
from ...lo.sdbc.driver_property_info import DriverPropertyInfo as DriverPropertyInfo
from ...lo.sdbc.file_connection_properties import FILEConnectionProperties as FILEConnectionProperties
from ...lo.sdbc.flat_connection_properties import FLATConnectionProperties as FLATConnectionProperties
from ...lo.sdbc.fetch_direction import FetchDirection as FetchDirection
from ...lo.sdbc.index_type import IndexType as IndexType
from ...lo.sdbc.jdbc_connection_properties import JDBCConnectionProperties as JDBCConnectionProperties
from ...lo.sdbc.key_rule import KeyRule as KeyRule
from ...lo.sdbc.odbc_connection_properties import ODBCConnectionProperties as ODBCConnectionProperties
from ...lo.sdbc.prepared_statement import PreparedStatement as PreparedStatement
from ...lo.sdbc.procedure_column import ProcedureColumn as ProcedureColumn
from ...lo.sdbc.procedure_result import ProcedureResult as ProcedureResult
from ...lo.sdbc.result_set import ResultSet as ResultSet
from ...lo.sdbc.result_set_concurrency import ResultSetConcurrency as ResultSetConcurrency
from ...lo.sdbc.result_set_type import ResultSetType as ResultSetType
from ...lo.sdbc.row_set import RowSet as RowSet
from ...lo.sdbc.sql_exception import SQLException as SQLException
from ...lo.sdbc.sql_warning import SQLWarning as SQLWarning
from ...lo.sdbc.statement import Statement as Statement
from ...lo.sdbc.transaction_isolation import TransactionIsolation as TransactionIsolation
from ...lo.sdbc.x_array import XArray as XArray
from ...lo.sdbc.x_batch_execution import XBatchExecution as XBatchExecution
from ...lo.sdbc.x_blob import XBlob as XBlob
from ...lo.sdbc.x_clob import XClob as XClob
from ...lo.sdbc.x_closeable import XCloseable as XCloseable
from ...lo.sdbc.x_column_locate import XColumnLocate as XColumnLocate
from ...lo.sdbc.x_connection import XConnection as XConnection
from ...lo.sdbc.x_connection_pool import XConnectionPool as XConnectionPool
from ...lo.sdbc.x_data_source import XDataSource as XDataSource
from ...lo.sdbc.x_database_meta_data import XDatabaseMetaData as XDatabaseMetaData
from ...lo.sdbc.x_database_meta_data2 import XDatabaseMetaData2 as XDatabaseMetaData2
from ...lo.sdbc.x_driver import XDriver as XDriver
from ...lo.sdbc.x_driver_access import XDriverAccess as XDriverAccess
from ...lo.sdbc.x_driver_manager import XDriverManager as XDriverManager
from ...lo.sdbc.x_driver_manager2 import XDriverManager2 as XDriverManager2
from ...lo.sdbc.x_generated_result_set import XGeneratedResultSet as XGeneratedResultSet
from ...lo.sdbc.x_isolated_connection import XIsolatedConnection as XIsolatedConnection
from ...lo.sdbc.x_multiple_results import XMultipleResults as XMultipleResults
from ...lo.sdbc.x_out_parameters import XOutParameters as XOutParameters
from ...lo.sdbc.x_parameters import XParameters as XParameters
from ...lo.sdbc.x_pooled_connection import XPooledConnection as XPooledConnection
from ...lo.sdbc.x_prepared_batch_execution import XPreparedBatchExecution as XPreparedBatchExecution
from ...lo.sdbc.x_prepared_statement import XPreparedStatement as XPreparedStatement
from ...lo.sdbc.x_ref import XRef as XRef
from ...lo.sdbc.x_result_set import XResultSet as XResultSet
from ...lo.sdbc.x_result_set_meta_data import XResultSetMetaData as XResultSetMetaData
from ...lo.sdbc.x_result_set_meta_data_supplier import XResultSetMetaDataSupplier as XResultSetMetaDataSupplier
from ...lo.sdbc.x_result_set_update import XResultSetUpdate as XResultSetUpdate
from ...lo.sdbc.x_row import XRow as XRow
from ...lo.sdbc.x_row_set import XRowSet as XRowSet
from ...lo.sdbc.x_row_set_listener import XRowSetListener as XRowSetListener
from ...lo.sdbc.x_row_update import XRowUpdate as XRowUpdate
from ...lo.sdbc.xsql_data import XSQLData as XSQLData
from ...lo.sdbc.xsql_input import XSQLInput as XSQLInput
from ...lo.sdbc.xsql_output import XSQLOutput as XSQLOutput
from ...lo.sdbc.x_statement import XStatement as XStatement
from ...lo.sdbc.x_struct import XStruct as XStruct
from ...lo.sdbc.x_warnings_supplier import XWarningsSupplier as XWarningsSupplier
