# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.util.alias_programmatic_pair import AliasProgrammaticPair as AliasProgrammaticPair
from ...lo.util.atom_class_request import AtomClassRequest as AtomClassRequest
from ...lo.util.atom_description import AtomDescription as AtomDescription
from ...lo.util.bootstrap_macro_expander import BootstrapMacroExpander as BootstrapMacroExpander
from ...lo.util.cell_protection import CellProtection as CellProtection
from ...lo.util.changes_event import ChangesEvent as ChangesEvent
from ...lo.util.changes_set import ChangesSet as ChangesSet
from ...lo.util.close_veto_exception import CloseVetoException as CloseVetoException
from ...lo.util.color import Color as Color
from ...lo.util.data_editor_event import DataEditorEvent as DataEditorEvent
from ...lo.util.data_editor_event_type import DataEditorEventType as DataEditorEventType
from ...lo.util.date import Date as Date
from ...lo.util.date_time import DateTime as DateTime
from ...lo.util.date_time_range import DateTimeRange as DateTimeRange
from ...lo.util.date_time_with_timezone import DateTimeWithTimezone as DateTimeWithTimezone
from ...lo.util.date_with_timezone import DateWithTimezone as DateWithTimezone
from ...lo.util.duration import Duration as Duration
from ...lo.util.element_change import ElementChange as ElementChange
from ...lo.util.endianness import Endianness as Endianness
from ...lo.util.invalid_state_exception import InvalidStateException as InvalidStateException
from ...lo.util.job_manager import JobManager as JobManager
from ...lo.util.language import Language as Language
from ...lo.util.macro_expander import MacroExpander as MacroExpander
from ...lo.util.malformed_number_format_exception import MalformedNumberFormatException as MalformedNumberFormatException
from ...lo.util.measure_unit import MeasureUnit as MeasureUnit
from ...lo.util.mode_change_event import ModeChangeEvent as ModeChangeEvent
from ...lo.util.not_locked_exception import NotLockedException as NotLockedException
from ...lo.util.not_numeric_exception import NotNumericException as NotNumericException
from ...lo.util.number_format import NumberFormat as NumberFormat
from ...lo.util.number_format_properties import NumberFormatProperties as NumberFormatProperties
from ...lo.util.number_format_settings import NumberFormatSettings as NumberFormatSettings
from ...lo.util.number_formats import NumberFormats as NumberFormats
from ...lo.util.number_formats_supplier import NumberFormatsSupplier as NumberFormatsSupplier
from ...lo.util.number_formatter import NumberFormatter as NumberFormatter
from ...lo.util.office_installation_directories import OfficeInstallationDirectories as OfficeInstallationDirectories
from ...lo.util.path_settings import PathSettings as PathSettings
from ...lo.util.path_substitution import PathSubstitution as PathSubstitution
from ...lo.util.replace_descriptor import ReplaceDescriptor as ReplaceDescriptor
from ...lo.util.revision_tag import RevisionTag as RevisionTag
from ...lo.util.search_algorithms import SearchAlgorithms as SearchAlgorithms
from ...lo.util.search_algorithms2 import SearchAlgorithms2 as SearchAlgorithms2
from ...lo.util.search_descriptor import SearchDescriptor as SearchDescriptor
from ...lo.util.search_flags import SearchFlags as SearchFlags
from ...lo.util.search_options import SearchOptions as SearchOptions
from ...lo.util.search_options2 import SearchOptions2 as SearchOptions2
from ...lo.util.search_result import SearchResult as SearchResult
from ...lo.util.sort_descriptor import SortDescriptor as SortDescriptor
from ...lo.util.sort_descriptor2 import SortDescriptor2 as SortDescriptor2
from ...lo.util.sort_field import SortField as SortField
from ...lo.util.sort_field_type import SortFieldType as SortFieldType
from ...lo.util.sortable import Sortable as Sortable
from ...lo.util.text_search import TextSearch as TextSearch
from ...lo.util.text_search2 import TextSearch2 as TextSearch2
from ...lo.util.time import Time as Time
from ...lo.util.time_with_timezone import TimeWithTimezone as TimeWithTimezone
from ...lo.util.tri_state import TriState as TriState
from ...lo.util.url import URL as URL
from ...lo.util.url_transformer import URLTransformer as URLTransformer
from ...lo.util.uri_abbreviation import UriAbbreviation as UriAbbreviation
from ...lo.util.veto_exception import VetoException as VetoException
from ...lo.util.x_accounting import XAccounting as XAccounting
from ...lo.util.x_atom_server import XAtomServer as XAtomServer
from ...lo.util.x_binary_data_container import XBinaryDataContainer as XBinaryDataContainer
from ...lo.util.x_broadcaster import XBroadcaster as XBroadcaster
from ...lo.util.x_cache_info import XCacheInfo as XCacheInfo
from ...lo.util.x_cancellable import XCancellable as XCancellable
from ...lo.util.x_chainable import XChainable as XChainable
from ...lo.util.x_changes_batch import XChangesBatch as XChangesBatch
from ...lo.util.x_changes_listener import XChangesListener as XChangesListener
from ...lo.util.x_changes_notifier import XChangesNotifier as XChangesNotifier
from ...lo.util.x_changes_set import XChangesSet as XChangesSet
from ...lo.util.x_cloneable import XCloneable as XCloneable
from ...lo.util.x_close_broadcaster import XCloseBroadcaster as XCloseBroadcaster
from ...lo.util.x_close_listener import XCloseListener as XCloseListener
from ...lo.util.x_closeable import XCloseable as XCloseable
from ...lo.util.x_data_editor import XDataEditor as XDataEditor
from ...lo.util.x_data_editor_listener import XDataEditorListener as XDataEditorListener
from ...lo.util.x_flush_listener import XFlushListener as XFlushListener
from ...lo.util.x_flushable import XFlushable as XFlushable
from ...lo.util.x_importable import XImportable as XImportable
from ...lo.util.x_indent import XIndent as XIndent
from ...lo.util.x_job_manager import XJobManager as XJobManager
from ...lo.util.x_link_update import XLinkUpdate as XLinkUpdate
from ...lo.util.x_localized_aliases import XLocalizedAliases as XLocalizedAliases
from ...lo.util.x_lockable import XLockable as XLockable
from ...lo.util.x_macro_expander import XMacroExpander as XMacroExpander
from ...lo.util.x_mergeable import XMergeable as XMergeable
from ...lo.util.x_mode_change_approve_listener import XModeChangeApproveListener as XModeChangeApproveListener
from ...lo.util.x_mode_change_broadcaster import XModeChangeBroadcaster as XModeChangeBroadcaster
from ...lo.util.x_mode_change_listener import XModeChangeListener as XModeChangeListener
from ...lo.util.x_mode_selector import XModeSelector as XModeSelector
from ...lo.util.x_modifiable import XModifiable as XModifiable
from ...lo.util.x_modifiable2 import XModifiable2 as XModifiable2
from ...lo.util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster
from ...lo.util.x_modify_listener import XModifyListener as XModifyListener
from ...lo.util.x_number_format_previewer import XNumberFormatPreviewer as XNumberFormatPreviewer
from ...lo.util.x_number_format_types import XNumberFormatTypes as XNumberFormatTypes
from ...lo.util.x_number_formats import XNumberFormats as XNumberFormats
from ...lo.util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier
from ...lo.util.x_number_formatter import XNumberFormatter as XNumberFormatter
from ...lo.util.x_number_formatter2 import XNumberFormatter2 as XNumberFormatter2
from ...lo.util.x_office_installation_directories import XOfficeInstallationDirectories as XOfficeInstallationDirectories
from ...lo.util.x_path_settings import XPathSettings as XPathSettings
from ...lo.util.x_property_replace import XPropertyReplace as XPropertyReplace
from ...lo.util.x_protectable import XProtectable as XProtectable
from ...lo.util.x_refresh_listener import XRefreshListener as XRefreshListener
from ...lo.util.x_refreshable import XRefreshable as XRefreshable
from ...lo.util.x_replace_descriptor import XReplaceDescriptor as XReplaceDescriptor
from ...lo.util.x_replaceable import XReplaceable as XReplaceable
from ...lo.util.x_search_descriptor import XSearchDescriptor as XSearchDescriptor
from ...lo.util.x_searchable import XSearchable as XSearchable
from ...lo.util.x_sortable import XSortable as XSortable
from ...lo.util.x_string_abbreviation import XStringAbbreviation as XStringAbbreviation
from ...lo.util.x_string_escape import XStringEscape as XStringEscape
from ...lo.util.x_string_mapping import XStringMapping as XStringMapping
from ...lo.util.x_string_substitution import XStringSubstitution as XStringSubstitution
from ...lo.util.x_string_width import XStringWidth as XStringWidth
from ...lo.util.x_text_search import XTextSearch as XTextSearch
from ...lo.util.x_text_search2 import XTextSearch2 as XTextSearch2
from ...lo.util.x_time_stamped import XTimeStamped as XTimeStamped
from ...lo.util.xurl_transformer import XURLTransformer as XURLTransformer
from ...lo.util.x_unique_id_factory import XUniqueIDFactory as XUniqueIDFactory
from ...lo.util.x_updatable import XUpdatable as XUpdatable
from ...lo.util.x_updatable2 import XUpdatable2 as XUpdatable2
from ...lo.util.x_veto import XVeto as XVeto
from ...lo.util.the_macro_expander import theMacroExpander as theMacroExpander
from ...lo.util.the_office_installation_directories import theOfficeInstallationDirectories as theOfficeInstallationDirectories
from ...lo.util.the_path_settings import thePathSettings as thePathSettings
