# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
from abc import abstractmethod
from .x_implicit_id_replace import XImplicitIDReplace as XImplicitIDReplace_49260fa7

class XImplicitIDContainer(XImplicitIDReplace_49260fa7):
    """
    makes it possible to insert and remove elements in/from a container using an implicit (unique) ID.

    See Also:
        `API XImplicitIDContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XImplicitIDContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.XImplicitIDContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.container.XImplicitIDContainer'

    @abstractmethod
    def addWithImplicitID(self, aElement: object) -> str:
        """
        adds a new object to the container and generates an implicit (unique) ID for this object.
        """
        ...
    @abstractmethod
    def removeByImplicitID(self, ID: str) -> None:
        """
        removes an object from the container which is specified by an implicit (unique) identifier.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XImplicitIDContainer']


